@@ -1,12 +1,50 @@
 use strict;
 use warnings;
 package Postfix::Parse::Mailq;
-{
-  $Postfix::Parse::Mailq::VERSION = '1.003';
-}
-use Mixin::Linewise::Readers -readers;
 # ABSTRACT: parse the output of the postfix mailq command
+$Postfix::Parse::Mailq::VERSION = '1.004';
+use Mixin::Linewise::Readers -readers;
 
+# =head1 SYNOPSIS
+#
+#   use Postfix::Parse::Mailq;
+#
+#   my $mailq_output = `mailq`;
+#   my $entries = Postfix::Parse::Mailq->read_string($mailq_output);
+#
+#   my $bytes = 0;
+#   for my $entry (@$entries) {
+#     next unless grep { /\@aol.com$/ } @{ $entry->{remaining_rcpts} };
+#     $bytes += $entry->{size};
+#   }
+#   
+#   print "$bytes bytes remain to send to AOL destinations\n";
+#
+# =head1 WARNING
+#
+# This code is really rough and the interface will change.  Entries will be
+# objects.  There will be some more methods.  Still, the basics are likely to
+# keep working, or keep pretty close to what you see here now.
+#
+# =method read_file
+#
+# =method read_handle
+#
+# =method read_string
+#
+#   my $entries = Postfix::Parse::Mailq->read_string($string, \%arg);
+#
+# This methods read the output of postfix's F<mailq> from a file (by name), a
+# filehandle, or a string, respectively.  They return an arrayref of hashrefs,
+# each hashref representing one entry in the queue as reported by F<mailq>.
+#
+# Valid arguments are:
+#
+#   spool - a hashref of { queue_id -> spool_name } pairs
+#           if given, this will be used to attempt to indicate in which
+#           spool messages currently are; it is not entirely reliable (race!)
+#
+# =cut
 
 sub read_handle {
   my ($self, $handle, $arg) = @_;
@@ -19,7 +57,7 @@ sub read_handle {
   return [] if $first eq 'Mail queue is empty';
 
   Carp::confess("first line did not appear to be first line of mailq output")
-    unless $first =~ m{\A-Queue ID-};
+    unless $first =~ m{\A-+Queue ID-+};
 
   my @current;
   my @entries;
@@ -44,6 +82,14 @@ sub read_handle {
   return \@entries;
 }
 
+# =method parse_block
+#
+#   my $entry = Mailq->parse_block(\@lines);
+#
+# Given all the lines in a single entry's block of lines in mailq output, this
+# returns data about the entry.
+#
+# =cut
 
 my %STATUS_FOR = (
   '!' => 'held',
@@ -62,7 +108,7 @@ sub parse_block {
 
   my ($qid, $status_chr, $size, $date, $sender) = $first =~ m/
     \A
-    ([A-F0-9]+)
+    ([A-F0-9]+|[0-9B-Zb-z]+)
     ([*!])?
     \s+
     (\d+)
@@ -92,13 +138,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Postfix::Parse::Mailq - parse the output of the postfix mailq command
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -154,7 +202,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2014 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
